@@ -3,7 +3,9 @@ package Amazon::API::Constants;
 use strict;
 use warnings;
 
-use parent qw{ Exporter };
+use Log::Log4perl::Level;
+
+use parent qw( Exporter );
 
 use Readonly;
 
@@ -11,16 +13,16 @@ our @EXPORT_OK = ();
 
 our %EXPORT_TAGS = (
   'booleans' => [
-    qw{
+    qw(
       $TRUE
       $FALSE
       $SUCCESS
       $FAILURE
-    }
+    )
   ],
 
   'chars' => [
-    qw{
+    qw(
       $AMPERSAND
       $COLON
       $COMMA
@@ -36,16 +38,18 @@ our %EXPORT_TAGS = (
       $SPACE
       $TEMPLATE_DELIMITER
       $UNDERSCORE
-    }
+    )
   ],
   'strings' => [
-    qw{
+    qw(
       $PADDING
-    }
+    )
   ],
+  'defaults' => [qw($DEFAULT_LOG4PERL_LAYOUT)],
+  'levels'   => [qw(%LOG4PERL_LOG_LEVELS)],
 );
 
-our $VERSION = '2.1.5';
+our $VERSION = '2.1.8';
 
 # chars
 Readonly::Scalar our $AMPERSAND          => q{&};
@@ -75,6 +79,17 @@ Readonly::Scalar our $FALSE => 0;
 Readonly::Scalar our $SUCCESS => 0;
 Readonly::Scalar our $FAILURE => 1;
 
+Readonly::Scalar our $DEFAULT_LOG4PERL_LAYOUT => '[%d{ISO8601}] %p %c - %m%n';
+
+Readonly::Hash our %LOG4PERL_LOG_LEVELS => (
+  error => $ERROR,
+  warn  => $WARN,
+  info  => $INFO,
+  debug => $DEBUG,
+  trace => $TRACE,
+  fatal => $FATAL,
+);
+
 foreach my $k ( keys %EXPORT_TAGS ) {
   push @EXPORT_OK, @{ $EXPORT_TAGS{$k} };
 }
